About
=====

The {package_name} package in the `Mys programming language`_.

Functions and types
===================

.. mysfile:: src/lib.mys

.. _Mys programming language: https://mys.readthedocs.io/en/latest/
